==> qtjambi-sql-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiSql/QSqlDriverCreatorBase_shell.cpp <==
#include "QSqlDriverCreatorBase_shell.h"
#include <QtJambi/Cast>

void deleter_QSqlDriverCreatorBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSqlDriverCreatorBase")
    QSqlDriverCreatorBase *_ptr = reinterpret_cast<QSqlDriverCreatorBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSqlDriverCreatorBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSqlDriverCreatorBase_shell) ); }

jmethodID QSqlDriverCreatorBase_oshell::__shell_javaMethod(int pos) const { return QSqlDriverCreatorBase_shell::__shell()->javaMethod(typeid(QSqlDriverCreatorBase), pos); }

// emitting (writeShellDestructor)
QSqlDriverCreatorBase_shell::~QSqlDriverCreatorBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSqlDriverCreatorBase::~QSqlDriverCreatorBase()", this)
    QSqlDriverCreatorBase_shell::__shell()->destructed(typeid(QSqlDriverCreatorBase));
}

// emitting (writeShellConstructor)
QSqlDriverCreatorBase_shell::QSqlDriverCreatorBase_shell()
    : QSqlDriverCreatorBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSqlDriverCreatorBase::QSqlDriverCreatorBase_shell()", this)
    QSqlDriverCreatorBase_shell::__shell()->constructed(typeid(QSqlDriverCreatorBase));
}

void QSqlDriverCreatorBase_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSqlDriverCreatorBase_oshell*>(ptr)->QSqlDriverCreatorBase_oshell::__shell()->tryDeleteShell(typeid(QSqlDriverCreatorBase));
}

// emitting Virtual overrides (virtualFunctions)
QSqlDriver* QSqlDriverCreatorBase_oshell::createObject() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSqlDriverCreatorBase::createObject()const", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSqlDriver*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QSqlDriverCreatorBase_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSqlDriver*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipForTopLevelObject(__jni_env, __qt_return_value);
                } else {
                    QSqlDriverCreatorBase_shell::__shell()->warnForMethod("QSqlDriverCreatorBase::createObject()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSqlDriverCreatorBase::createObject()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QSqlDriverCreatorBase_access::__qt_createObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSqlDriverCreatorBase::createObject() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSqlDriverCreatorBase::createObject() const.";
    } else {
        QSqlDriver* __qt_return_value = createObject();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QSqlDriverCreatorBase()
void __qt_construct_QSqlDriverCreatorBase(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSqlDriverCreatorBase()")
    Q_UNUSED(__java_arguments)
    QSqlDriverCreatorBase *__qt_this = new(__qtjambi_ptr) QSqlDriverCreatorBase_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QSqlDriverCreatorBase::QSqlDriverCreatorBase()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_sql_QSqlDriverCreatorBase_initialize_1native__Lio_qt_sql_QSqlDriverCreatorBase_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSqlDriverCreatorBase::QSqlDriverCreatorBase()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSqlDriverCreatorBase, sizeof(QSqlDriverCreatorBase_shell), typeid(QSqlDriverCreatorBase), 0, true, &deleter_QSqlDriverCreatorBase, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSqlDriverCreatorBase_shell
void __qt_destruct_QSqlDriverCreatorBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSqlDriverCreatorBase")
    reinterpret_cast<QSqlDriverCreatorBase_shell*>(ptr)->~QSqlDriverCreatorBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSqlDriverCreatorBase::createObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_sql_QSqlDriverCreatorBase_00024ConcreteWrapper_createObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSqlDriverCreatorBase *__qt_this = QtJambiAPI::objectFromNativeId<QSqlDriverCreatorBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSqlDriverCreatorBase::createObject()const", __this_nativeId)
        __java_return_value = static_cast<const QSqlDriverCreatorBase_access*>(__qt_this)->__qt_createObject_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSqlDriverCreatorBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSqlDriverCreatorBase>("QSqlDriverCreatorBase", "io/qt/sql/QSqlDriverCreatorBase");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "createObject", "()Lio/qt/sql/QSqlDriver;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSqlDriverCreatorBase, {
        ConstructorInfo(&__qt_construct_QSqlDriverCreatorBase, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSqlDriverCreatorBase);
    registerSizeOfShell(typeId, sizeof(QSqlDriverCreatorBase_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-sql-debuginfo-linux-x64-6.5.9.jar: sources/QtJambiSql/QSqlDriverCreatorBase_shell.cpp <==
#include "QSqlDriverCreatorBase_shell.h"
#include <QtJambi/Cast>

void deleter_QSqlDriverCreatorBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSqlDriverCreatorBase")
    QSqlDriverCreatorBase *_ptr = reinterpret_cast<QSqlDriverCreatorBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSqlDriverCreatorBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSqlDriverCreatorBase_shell) ); }

jmethodID QSqlDriverCreatorBase_oshell::__shell_javaMethod(int pos) const { return QSqlDriverCreatorBase_shell::__shell()->javaMethod(typeid(QSqlDriverCreatorBase), pos); }

// emitting (writeShellDestructor)
QSqlDriverCreatorBase_shell::~QSqlDriverCreatorBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSqlDriverCreatorBase::~QSqlDriverCreatorBase()", this)
    QSqlDriverCreatorBase_shell::__shell()->destructed(typeid(QSqlDriverCreatorBase));
}

// emitting (writeShellConstructor)
QSqlDriverCreatorBase_shell::QSqlDriverCreatorBase_shell()
    : QSqlDriverCreatorBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSqlDriverCreatorBase::QSqlDriverCreatorBase_shell()", this)
    QSqlDriverCreatorBase_shell::__shell()->constructed(typeid(QSqlDriverCreatorBase));
}

void QSqlDriverCreatorBase_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSqlDriverCreatorBase_oshell*>(ptr)->QSqlDriverCreatorBase_oshell::__shell()->tryDeleteShell(typeid(QSqlDriverCreatorBase));
}

// emitting Virtual overrides (virtualFunctions)
QSqlDriver* QSqlDriverCreatorBase_oshell::createObject() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSqlDriverCreatorBase::createObject()const", this)
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QSqlDriver*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QSqlDriverCreatorBase_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QSqlDriver*>(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnershipForTopLevelObject(__jni_env, __qt_return_value);
                } else {
                    QSqlDriverCreatorBase_shell::__shell()->warnForMethod("QSqlDriverCreatorBase::createObject()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSqlDriverCreatorBase::createObject()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return nullptr;
        }
    }else{
        return nullptr;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QSqlDriverCreatorBase_access::__qt_createObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QSqlDriverCreatorBase::createObject() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QSqlDriverCreatorBase::createObject() const.";
    } else {
        QSqlDriver* __qt_return_value = createObject();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QSqlDriverCreatorBase()
void __qt_construct_QSqlDriverCreatorBase(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSqlDriverCreatorBase()")
    Q_UNUSED(__java_arguments)
    QSqlDriverCreatorBase *__qt_this = new(__qtjambi_ptr) QSqlDriverCreatorBase_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QSqlDriverCreatorBase::QSqlDriverCreatorBase()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_sql_QSqlDriverCreatorBase_initialize_1native__Lio_qt_sql_QSqlDriverCreatorBase_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSqlDriverCreatorBase::QSqlDriverCreatorBase()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSqlDriverCreatorBase, sizeof(QSqlDriverCreatorBase_shell), typeid(QSqlDriverCreatorBase), 0, true, &deleter_QSqlDriverCreatorBase, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSqlDriverCreatorBase_shell
void __qt_destruct_QSqlDriverCreatorBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSqlDriverCreatorBase")
    reinterpret_cast<QSqlDriverCreatorBase_shell*>(ptr)->~QSqlDriverCreatorBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSqlDriverCreatorBase::createObject()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_sql_QSqlDriverCreatorBase_00024ConcreteWrapper_createObject_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSqlDriverCreatorBase *__qt_this = QtJambiAPI::objectFromNativeId<QSqlDriverCreatorBase>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSqlDriverCreatorBase::createObject()const", __this_nativeId)
        __java_return_value = static_cast<const QSqlDriverCreatorBase_access*>(__qt_this)->__qt_createObject_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSqlDriverCreatorBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSqlDriverCreatorBase>("QSqlDriverCreatorBase", "io/qt/sql/QSqlDriverCreatorBase");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "createObject", "()Lio/qt/sql/QSqlDriver;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSqlDriverCreatorBase, {
        ConstructorInfo(&__qt_construct_QSqlDriverCreatorBase, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSqlDriverCreatorBase);
    registerSizeOfShell(typeId, sizeof(QSqlDriverCreatorBase_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
